@@ -207,7 +207,7 @@ class ClearingHouse:
 
         if isinstance(user_id, int):
             user_id = [user_id]
-        assert len(user_id) == len(authority)
+        assert len(user_id) == len(authority) or len(user_id) == 0
 
         accounts = []
         for pk, id in zip(authority, user_id):
@@ -250,9 +250,6 @@ class ClearingHouse:
                     market_index = position.market_index
                     await track_market(market_index, is_writable=True)
 
-            if writable_market_index is not None:
-                await track_market(writable_market_index, is_writable=True)
-
             if include_spot_markets:
                 for spot_market_balance in user_account.spot_positions:
                     if not is_spot_position_available(spot_market_balance):
@@ -267,12 +264,15 @@ class ClearingHouse:
                     for i in readable_spot_market_index:
                         await track_spot_market(i, is_writable=False)
 
-                if writable_spot_market_index is not None:
-                    if isinstance(writable_spot_market_index, int):
-                        writable_spot_market_index = [writable_spot_market_index]
+        if writable_market_index is not None:
+            await track_market(writable_market_index, is_writable=True)
 
-                    for i in writable_spot_market_index:
-                        await track_spot_market(i, is_writable=True)
+        if writable_spot_market_index is not None and include_spot_markets:
+            if isinstance(writable_spot_market_index, int):
+                writable_spot_market_index = [writable_spot_market_index]
+
+            for i in writable_spot_market_index:
+                await track_spot_market(i, is_writable=True)
 
         remaining_accounts = [
             *oracle_map.values(),
@@ -1271,7 +1271,8 @@ class ClearingHouse:
         amount: int,
     ):
         ra = await self.get_remaining_accounts(
-            writable_spot_market_index=spot_market_index
+            writable_spot_market_index=spot_market_index, 
+            user_id=[] # dont need the user account (might not exist)
         )
 
         return self.program.instruction["request_remove_insurance_fund_stake"](
@@ -1297,6 +1298,44 @@ class ClearingHouse:
             ),
         )
 
+    async def cancel_request_remove_insurance_fund_stake(self, spot_market_index: int):
+        return await self.send_ixs(
+            await self.get_cancel_request_remove_insurance_fund_stake_ix(spot_market_index)
+        )
+
+    async def get_cancel_request_remove_insurance_fund_stake_ix(self, spot_market_index: int):
+        ra = await self.get_remaining_accounts(
+            writable_spot_market_index=spot_market_index
+        )
+
+        return self.program.instruction["cancel_request_remove_insurance_fund_stake"](
+            spot_market_index,
+            ctx=Context(
+                accounts={
+                    "state": get_state_public_key(self.program_id),
+                    "spot_market": get_spot_market_public_key(
+                        self.program_id, spot_market_index
+                    ),
+                    "insurance_fund_stake": get_insurance_fund_stake_public_key(
+                        self.program_id, self.authority, spot_market_index
+                    ),
+                    "user_stats": get_user_stats_account_public_key(
+                        self.program_id, self.authority
+                    ),
+                    "authority": self.authority,
+                    "insurance_fund_vault": get_insurance_fund_vault_public_key(
+                        self.program_id, spot_market_index
+                    ),
+                    "drift_signer": get_clearing_house_signer_public_key(
+                        self.program_id
+                    ),
+                    "user_token_account": self.spot_market_atas[spot_market_index],
+                    "token_program": TOKEN_PROGRAM_ID,
+                },
+                remaining_accounts=ra,
+            ),
+        )
+
     async def remove_insurance_fund_stake(self, spot_market_index: int):
         return await self.send_ixs(
             await self.get_remove_insurance_fund_stake_ix(spot_market_index)
@@ -1304,7 +1343,8 @@ class ClearingHouse:
 
     async def get_remove_insurance_fund_stake_ix(self, spot_market_index: int):
         ra = await self.get_remaining_accounts(
-            writable_spot_market_index=spot_market_index
+            writable_spot_market_index=spot_market_index, 
+            user_id=[] # dont need the user account (might not exist)
         )
 
         return self.program.instruction["remove_insurance_fund_stake"](
